#!/bin/false
"""Scanners.py: The threaded scanning class for ddrgen
Copyright 2006 Michael Farrell.
"""

from xml.sax.saxutils import escape
from threading import Thread
import tempfile, os
import ddrghelpers

class NetBIOSScannerThread(Thread):
	def __init__(self, ip):
		"""Initialise the thread."""
		Thread.__init__(self)
		self.ip = ip
		self.result = []

	def run(self):
		"""Run the scanner thread."""

		fh = os.popen("nmblookup -A " + self.ip + " | grep \'<00>\' | grep -v GROUP | awk \'{print $1}\'")
		self.result = (self.ip, fh.readline().replace("\n", "").lower())
		fh.close()



class ShareScannerThread(Thread):
	"""This class is more complex, it's used for generating the stats.xml files."""
	def __init__(self, ip, name, scanForGames, genDDRHelper, isddrhost):
		"""Initialise the thread."""

		Thread.__init__(self)
		self.ip = ip
		self.name = name
		self.result = ""
		self.scanForGames = scanForGames
		self.genDDRHelper = genDDRHelper
		self.isddrhost = isddrhost

	def run(self):
		"""Run the scanner thread."""
		osList = ddrghelpers.osList()
		serverToOsList = ddrghelpers.serverToOsList()

		fh = os.popen("smbclient -gNL " + self.ip + " 2>&1")
		serverinfo = fh.readlines()
		fh.close()

		servstring = serverinfo[0].split("]")
		
		try:
			servOS = servstring[1][5:]
		except:
			servOS = "Unknown"
		
		try:
			servServer = servstring[2][9:]
		except:
			servServer = "Unknown"
				
		osSuccess = 0
		try:
			osSuccess = osList[servOS][1]
			servOS = osList[servOS][0]
		except:
			print "WARNING: Unrecogized OS '" + servOS + "' on '" + self.name + "' (" + self.ip + ") . If you know it's OS, please contact me so more OSes can be put in the database."
		
		# try to guess OS from server name
		if osSuccess != 1:
			try:
				if serverToOsList[servServer] != "GENERIC":
					servOS = serverToOsList[servServer]
			except:
				print "WARNING: Unknown server name and unsatisfied with reported OS information (" + servOS + ").  The server name was '" + servServer + "', running on '" + self.name + "' (" + self.ip + ") . If you know it's OS and/or server software, please contact me so more OSes and servers can be put in the database."
		diskinfo = "<shares>"
		for disk in serverinfo:
			disk = disk[:-1] # trim nl
			if (disk[:3] != "Ano") and (disk[:3] != "Dom"): # skip more messages...
				diskdata = disk.split("|")
				if diskdata[0] == "Disk":
					# append disk data.
					diskinfo = diskinfo + "<share><type>smb</type><name>" + escape(diskdata[1]).encode('utf8', 'xmlcharrefreplace') + "</name><comment>" + escape(diskdata[2]).encode('utf8', 'xmlcharrefreplace') + "</comment></share>"
		diskinfo = diskinfo + "</shares>"
		
		# GAMES SCANNING
		if self.scanForGames:
			# look for ut200x
			ut2004stats = ut2004.retrieveStatus(self.ip)
			ut2004data = ""
			if ut2004stats != 0:
				ut2004data = "<game>"
				# there is a ut2004 server, get data!
				for nameU, valueU in ut2004stats[0].iteritems():
					ut2004data = ut2004data + "<" + nameU.replace(" ", "") + ">" + str(valueU) + "</" + nameU + ">"
				for nameU, valueU in ut2004stats[1].iteritems():
					ut2004data = ut2004data + "<" + nameU.replace(" ", "") + ">" + str(valueU) + "</" + nameU + ">"
				ut2004data = ut2004data + "</game>"

			# look for q3a
			tempdata = ""
			tempstats = q3a.retrieveStatus(self.ip)
			if tempstats != 0:
				tempdata = "<game>"
				for nameU, valueU in tempstats.iteritems():
					tempdata = tempdata + "<" + nameU.replace(" ", "") + ">" + str(valueU) + "</" + nameU + ">"
				q3adata = tempdata + "</game>"		
			else:
				q3adata = ""

			# look for Call of Duty
			tempdata = ""
			tempstats = q3a.retrieveStatus(self.ip, 28960)
			if tempstats != 0:
				tempdata = "<game>"
				for nameU, valueU in tempstats.iteritems():
					tempdata = tempdata + "<" + nameU.replace(" ", "") + ">" + str(valueU) + "</" + nameU + ">"
				coddata = tempdata + "</game>"		
			else:
				coddata = ""

		result = "<computer><ip>" + self.ip + "</ip><name>" + self.name + "</name><os>" + servOS + "</os><server>" + servServer + "</server>" + diskinfo
		if self.scanForGames:
			if (len(ut2004data + q3adata + coddata) > 0):
				result = result + "<games>" + ut2004data + q3adata + coddata + "</games>"
				
		if self.genDDRHelper:
			# DDRHepler bits
			if self.isddrhost:
				# then it's a ddrhelper host
				ddrhdata = ddrghelpers.getServicesFromDDRHelper(self.ip)
				result = result + "<ddrhelper>"
				for service in ddrhdata:
					result = result + "<service><type>" + service[0] + "</type><name>" + service[1] + "</name><enabled>" + service[2] + "</enabled><url>" + service[3] + "</url><description>" + service[4] + "</description><port>" + service[5] + "</port>"
					result = result + "<properties>"
					for prop in service[6]:
						result = result + "<property><label>" + prop[0] + "</label><value>" + prop[1] + "</value></property>"
					result = result + "</properties></service>"
				result = result + "</ddrhelper>"
				
		result = result + "</computer>\n"

		# end! :)
		self.result = result
