#!/bin/false
# Quake III Arena ServerInfo module in Python
# Copyright 2005 Michael Farrell
#
# Derived from gsQuery.
#
# Using the library is simple, just call retrieveStatus with the server IP
# address.  The optional second parameter is the query port, which is by
# default is 27960 (Quake III).  There are other ports of intrest:
#
# Call of Duty (and CoD:UO) - 28960
#

import string, struct, time
from twisted.internet.protocol import DatagramProtocol
from twisted.internet import reactor

def retrieveStatus(host, qport = 27960, lag = 1):
	class q3aconn(DatagramProtocol):
		def startProtocol(self):
			# init store
			global storedata
			global waitcount
			waitcount = 0
			storedata = ""

			# connect and request info
			self.transport.connect(host, qport)
			self.transport.write("\xFF\xFF\xFF\xFF\x02getstatus\x0a\x00")
	        
		def datagramReceived(self, data, (host, port)):
			global storedata
			# collect data
			storedata = storedata + data

			if len(storedata) >= 5:
				# we are expecting five packets tops, stop at that.
				reactor.stop()

		def connectionRefused(self):
			print "Noone listening"

	# 0 means any port, we don't care
	reactor.listenUDP(0, q3aconn())
	reactor.callLater(lag, reactor.stop)
	reactor.run()

	try:
		returnedData = parseData(storedata)
		returnedData['gameport'] = qport
		return returnedData
	except:
		return 0

def parseData(data):
	# We skip down to the character after \x0A, and then separate by backslashes
	data = data.split("\x0A")[1][1:].split("\\")

	# Friendly naming stuff for server flags.  This only applies to SOME flags,
	# that is the true or false ones.
	friendlyFlags = {
		"sv_floodProtect": "Flood_Protection",
		"sv_pure": "Pure",
		"sv_allowAnonymous": "Allow_Anon_Clients",
		"sv_punkbuster": "PunkBuster",
		"g_needpass": "Password_Protection",

		# Call of Duty flags
		"scr_friendlyfire": "Friendly_Fire",
		"scr_allow_tanks": "Tanks_Allowed",
		"scr_killcam": "Killcam",
		"scr_allow_jeeps": "Jeeps_Allowed",
		"pswrd": "Password_Protection"
	}

	friendlyGameNames = {
		"CoD:United Offensive": "Call of Duty: United Offensive",
		"baseq3": "Quake III Arena"
	}

	friendlyGameTypes = {
		"0": "Deathmatch", #q3a
		"dm": "Deathmatch" #cod
	}

	x = 0
	gameinfo = {}

	while x < len(data):
		if (friendlyFlags.has_key(data[x])):
			gameinfo[friendlyFlags[data[x]]] = data[x+1]
		else:
			gameinfo[data[x]] = data[x+1]
		x = x + 2

	if friendlyGameNames.has_key(gameinfo['gamename']):
		gameinfo['gamename'] = friendlyGameNames[gameinfo['gamename']]

	if friendlyGameTypes.has_key(gameinfo['g_gametype']):
		gameinfo['g_gametype'] = friendlyGameTypes[gameinfo['g_gametype']]

	gameinfo['type'] = 'q3a'
	return gameinfo
