<?xml version="1.0" encoding="ISO-8859-1"?>
<xsl:stylesheet version="1.0" xmlns:xsl="http://www.w3.org/1999/XSL/Transform">

<xsl:template match="/stats">
	<html>
		<head>
			<title>Network Status</title>
			<style type="text/css">
				table {
					border: 1px #000 solid;
					width: 100%;
				}

				table td table {
					border: 1px #ff0 dotted;
					margin: 10px;
				}

				table td table td.first {
					width: 100px;
				}

				table th {
					border: 1px #000 solid;
				}

				body {
					color: #fff;
					background-color: #000;
					font-family: sans-serif;
				}

				td.highlight {
					font-weight: bold;
					background-color: #ff0;
					color: #000;
				}

				td.ghead {
					border: 1px #000 dotted;
					font-weight:bold;
				}

				pre {
					white-space: pre-wrap;
					white-space: -moz-pre-wrap;
					white-space: -pre-wrap;
					white-space: -o-pre-wrap;
					word-wrap: break-word;
					font-family: sans-serif;
				}

				a:link {
					color: #77f;
				}
			</style>
			<meta http-equiv="Refresh" content="60" />
		</head>
		<body>
			<h1>Network Status</h1>

			<p>Please note: links to <abbr title="Server Message Block">SMB</abbr>/<abbr title="Common Internet File System">CIFS</abbr> shares only work on Windows.  Because of security implications, the links do not work in Mozilla-based browsers by default.  Please <a href="http://kb.mozillazine.org/Firefox_:_Issues_:_Links_to_Local_Pages_Don't_Work">allow this site</a> to use links to local pages to over-ride this feature.</p>

			<p>If you want to advertise services, install <a href="http://micolous.id.au/projects/ddrgen/ddrhelper/">DDRHelper</a>.</p>

			<p>This page was last updated: <code><xsl:value-of select="updated" /></code>.  This page will reload automatically every minute, and is updated every 5 minutes.</p>

			<table>
				<tr>
					<th>IP</th>
					<th>Name</th>
					<th>OS</th>
					<th>Server</th>
				</tr>
				<xsl:for-each select="computer">
					<tr>
						<td class="highlight"><xsl:value-of select="ip" /></td>
						<td class="highlight"><xsl:value-of select="name" /></td>
						<td><xsl:value-of select="os" /></td>
						<td><xsl:value-of select="server" /></td>
					</tr>
					<!-- start shares -->
					<xsl:if test="shares/share">
						<tr>
							<td colspan="4">
								<table>
									<xsl:for-each select="shares/share">
										<tr>
											<xsl:choose>
												<xsl:when test="type='smb'">
												<td><a href="file://///{../../ip}/{name}/"><xsl:value-of select="name" /></a></td><td><xsl:value-of select="comment" /></td>
												</xsl:when>
												<xsl:otherwise>
												</xsl:otherwise>
											</xsl:choose>

										</tr>
									</xsl:for-each>
								</table>
							</td>
						</tr>
					</xsl:if>
					<!-- end shares -->
					<!-- start games -->
					<xsl:if test="games/game">
						<tr>
							<td colspan="4">
								<table>
									<xsl:for-each select="games/game">
										<tr>
											<xsl:choose>
												<xsl:when test="type='q3a'">
													<!-- QUAKE 3 ENGINE -->
													<table>
														<tr>
															<td colspan="2" class="ghead"><xsl:value-of select="gamename" /> (Version <xsl:value-of select="shortversion" /> <xsl:value-of select="version" /> , Protocol Version <xsl:value-of select="protocol" />)</td>
														</tr>

														<tr>
															<td>Server Name:</td>
															<td><xsl:value-of select="sv_hostname" /></td>
														</tr>
														<tr>
															<td>Gametype/Map:</td>
															<td><xsl:value-of select="g_gametype" /> in <xsl:value-of select="mapname" /></td>
														</tr>

														<tr>
															<td>Max Players:</td>
															<td><xsl:value-of select="sv_maxclients" /></td>
														</tr>
	<!-- TODO: Implement Flags
														<tr>
															<td>Flags:</td>
															<td></td>
														</tr>
	-->
														<tr>
															<td colspan="2">
																<xsl:choose>
																	<xsl:when test="gamename='Call of Duty: United Offensive'">
																		<a href="coduo://{../../ip}:{port}">Join This Game</a>
																	</xsl:when>
																	<xsl:when test="gamename='Call of Duty'">
																		<a href="cod://{../../ip}:{port}">Join This Game</a>
																	</xsl:when>
																	<xsl:otherwise>
																		<a href="q3a://{../../ip}:{port}">Join This Game</a>
																	</xsl:otherwise>
																</xsl:choose>
															</td>
														</tr>
													</table>
													<!-- end quake 3 arena -->
												</xsl:when>
												<xsl:when test="type='ut2004'">
													<!-- UT2004 ENGINE -->
													<table>
														<tr>
															<td colspan="2" class="ghead"><xsl:value-of select="gamename" /> (Version <xsl:value-of select="serverversion" />)</td>
														</tr>

														<tr>
															<td>Server Name:</td>
															<td><xsl:value-of select="servername" /></td>
														</tr>
														<tr>
															<td>Gametype/Map:</td>
															<td><xsl:value-of select="gametype" /> in <xsl:value-of select="gamemap" /></td>
														</tr>

														<tr>
															<td>Current Players:</td>
															<td><xsl:value-of select="currentplayers" /> (of <xsl:value-of select="maxplayers" /> max)</td>
														</tr>

														<tr>
															<td>Mutators:</td>
															<td>
																<xsl:for-each select="mutator">
																	<xsl:value-of select="." />
																</xsl:for-each>
															</td>
														</tr>

														<tr>
															<td colspan="2">
																<a href="ut2004://{../../ip}:{port}">Join This Game</a>
															</td>
														</tr>
													</table>
													<!-- end ut2004 -->
												</xsl:when>
												<xsl:otherwise>
													<!-- ignore unknown -->
												</xsl:otherwise>
											</xsl:choose>
										</tr>
									</xsl:for-each>

								</table>
							</td>
						</tr>
					</xsl:if>
					<!-- end games -->

					<!-- start ddrhelper -->
					<xsl:if test="ddrhelper/service">
						<tr>
							<td colspan="4">
								<p>This is a <a href="http://{ip}:6565/">DDRHelper enabled host</a>!</p>
								<table>
									<tr>
										<th colspan="2">Service Type</th>
										<th>Name</th>
										<th>Description</th>
									</tr>
									<xsl:for-each select="ddrhelper/service">
										<tr>
											<xsl:variable name="idx" select="position()-1" />
											<td><img src="http://{../../ip}:6565/icon/{$idx}" /></td>
											<td><xsl:value-of select="type" /></td>
											<td><xsl:value-of select="name" /></td>
											<td><pre><xsl:value-of select="description" /></pre></td>
											<td><a href="{url}">Connect</a></td>
											<td><a href="http://{../../ip}:6565/info/{$idx}">Information</a></td>
										</tr>
									</xsl:for-each>
								</table>
							</td>
						</tr>
					</xsl:if>	

					<!-- end ddrhelper -->
				</xsl:for-each>
			</table>
		</body>
	</html>
</xsl:template>


</xsl:stylesheet>
